.. image:: https://github.com/AndreaBlengino/baypy/blob/master/docs/source/_static/logo.png?raw=true
   :alt: Logo

Bayesian Monte Carlo Markov Chain Regression
--------------------------------------------

**baypy** is a python package for solving bayesian regression models
through a Monte Carlo Markov chain sampling.

.. list-table::
   :stub-columns: 1
   :widths: auto
   :width: 100%

   * - Release
     - |pypi_release| |build|
   * - Versioning
     - |supported_python_versions| |semver| |dependencies|
   * - Tests
     - |linux_tests| |macos_tests| |windows_tests| |test_coverage|
   * - Documentation
     - |docs|
   * - Code Quality
     - |codefactor_grade| |codacy_grade| |issues|
   * - License
     - |license|

.. |pypi_release| image:: https://img.shields.io/pypi/v/baypy?label=release&color=blue
   :target: https://pypi.org/project/baypy/
   :alt: PyPI - Library Version

.. |build| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/baypy/release.yml.svg?logo=github
   :target: https://github.com/AndreaBlengino/baypy/actions/workflows/release.yml
   :alt: Package Build

.. |supported_python_versions| image:: https://img.shields.io/pypi/pyversions/baypy?logo=python&logoColor=gold
   :target: https://pypi.org/project/baypy/
   :alt: PyPI - Supported Python Versions

.. |semver| image:: https://img.shields.io/badge/semver-2.0.0-blue.svg
   :target: https://semver.org/

.. |dependencies| image:: https://dependency-dash.repo-helper.uk/github/AndreaBlengino/baypy/badge.svg
   :target: https://dependency-dash.repo-helper.uk/github/AndreaBlengino/baypy
   :alt: Dependencies Status

.. |linux_tests| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/baypy/linux_test.yml.svg?logo=linux&logoColor=white&label=Linux
   :target: https://github.com/AndreaBlengino/baypy/actions/workflows/linux_test.yml
   :alt: Linux Tests

.. |macos_tests| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/baypy/macos_test.yml.svg?logo=apple&label=macOS
   :target: https://github.com/AndreaBlengino/baypy/actions/workflows/macos_test.yml
   :alt: macOS Tests

.. |windows_tests| image:: https://img.shields.io/github/actions/workflow/status/AndreaBlengino/baypy/windows_test.yml.svg?logo=windows&label=Windows
   :target: https://github.com/AndreaBlengino/baypy/actions/workflows/windows_test.yml
   :alt: Windows Tests

.. |test_coverage| image:: https://img.shields.io/codecov/c/github/AndreaBlengino/baypy/master?logo=codecov
   :target: https://codecov.io/gh/AndreaBlengino/baypy
   :alt: Test Coverage

.. |docs| image:: https://img.shields.io/readthedocs/baypy/latest?logo=read%20the%20docs
   :target: https://baypy.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Build Status

.. |codefactor_grade| image:: https://img.shields.io/codefactor/grade/github/AndreaBlengino/baypy?logo=codefactor&label=CodeFactor
   :target: https://www.codefactor.io/repository/github/andreablengino/baypy
   :alt: CodeFactor Grade

.. |codacy_grade| image:: https://img.shields.io/codacy/grade/132c2f3d93344ae0934ea808bbf17f05?logo=codacy&label=Codacy
   :target: https://app.codacy.com/gh/AndreaBlengino/baypy/dashboard
   :alt: Codacy Grade

.. |issues| image:: https://img.shields.io/github/issues/AndreaBlengino/baypy?logo=github
   :target: https://github.com/AndreaBlengino/baypy/issues
   :alt: Open Issues

.. |license| image:: https://img.shields.io/badge/License-GPLv3-blue.svg
   :target: https://github.com/AndreaBlengino/baypy/blob/master/LICENSE
   :alt: License


References
----------

- `Installation <https://baypy.readthedocs.io/en/latest/installation.html>`_
- `PyPI <https://pypi.org/project/baypy>`_
- `Documentation <https://baypy.readthedocs.io/en/latest/?badge=latest>`_
- `Usage Examples <https://baypy.readthedocs.io/en/latest/examples/index.html>`_
- `Issue tracker <https://github.com/AndreaBlengino/baypy/issues>`_
- `Source code <https://github.com/AndreaBlengino/baypy/tree/master/baypy>`_
- `GNU General Public License v3.0 <https://github.com/AndreaBlengino/baypy/blob/master/LICENSE>`_
- `Release Notes <https://baypy.readthedocs.io/en/latest/release_notes/index.html>`_


Contributing
------------

The baypy project welcomes your expertise and enthusiasm!  
All contributions, bug reports, bug fixes, documentation improvements, 
enhancements and ideas are welcome.  
Writing code isn't the only way to contribute to baypy. You can also:

- develop tutorials, presentations and other educational materials
- maintain and improve the `documentation <https://baypy.readthedocs.io/en/latest/?badge=latest>`_,
- help with outreach and onboard new contributors

Have a look at the `contributing guide <https://github.com/AndreaBlengino/baypy/blob/master/.github/CONTRIBUTING.md>`_.
If you are new to contributing to open source, `this guide <https://opensource.guide/how-to-contribute/>`_ helps explain
why, what, and how to successfully get involved.
